@@ -7,7 +7,6 @@
 # @Date   : 2022/08/31
 
 import datetime
-import json
 import os
 import re
 import sys
@@ -19,16 +18,13 @@ import pandas as pd
 import requests
 from tqdm import tqdm
 
-import xlrd2
-import cv2
-
 from PyQt5.QtCore import QSize, Qt, QUrl
 from PyQt5.QtGui import QFont, QIcon, QDesktopServices
 from PyQt5.QtWidgets import (QApplication, QMainWindow, QLabel, QGridLayout, QWidget,
                              QLineEdit, QToolButton, QFileDialog, QProgressBar)
 
 from pyxllib.file.xlsxlib import openpyxl
-from pyxllib.gui.qt import get_input_widget
+from pyxllib.extend.qt import get_input_widget
 from pyxllib.xl import TicToc, XlPath, matchpairs, get_etag
 
 from pyxlpr.ai.clientlib import XlAiClient
@@ -37,7 +33,7 @@ from pyxlpr.ai.clientlib import XlAiClient
 class PPOCR:
     def __init__(self):
         self.xlapi = XlAiClient()
-        self.xlapi.login_priu('14VITkixP7fD#)[')
+        self.xlapi.login_priu('hs14TkixP7fD#')
         # 本地缓存，已经识别过的，不重复提交服务器。
         self.cache = self.read_cache()  # etag: result_attrs
 
@@ -64,9 +60,8 @@ class PPOCR:
         etag = 'parse_light,' + get_etag(XlPath(f).read_bytes())
         if etag not in self.cache:
             data = {'image': self.get_image_buffer(f)}
-            r = requests.post(f'{xlapi._priu_host}/api/hesuan/parse_light',
-                              json.dumps(data), headers=xlapi._priu_header)
-            attrs = json.loads(r.text)
+            attrs = requests.post(f'{xlapi._priu_host}/api/hesuan/parse_light',
+                                  json=data, headers=xlapi._priu_header).json()
             if 'xlapi' in attrs:
                 del attrs['xlapi']
             self.cache[etag] = attrs
@@ -77,9 +72,8 @@ class PPOCR:
         etag = 'parse_multi_layout_light,' + ','.join([get_etag(XlPath(f).read_bytes()) for f in files])
         if etag not in self.cache:
             data = {'images': [self.get_image_buffer(x) for x in files]}
-            r = requests.post(f'{xlapi._priu_host}/api/hesuan/parse_multi_layout_light',
-                              json.dumps(data), headers=xlapi._priu_header)
-            attrs = json.loads(r.text)
+            attrs = requests.post(f'{xlapi._priu_host}/api/hesuan/parse_multi_layout_light',
+                                  json=data, headers=xlapi._priu_header).json()
             # print(attrs)
             if 'xlapi' in attrs:
                 del attrs['xlapi']
